==> haskell-mmap-0.5.9-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mmap.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mmap
version: 0.5.9
id: mmap-0.5.9-EWtfmxbT8jF8qY63lOubUM
key: mmap-0.5.9-EWtfmxbT8jF8qY63lOubUM
license: BSD3
copyright: 2008-2012, Gracjan Polak
maintainer: Gracjan Polak <gracjanpolak@gmail.com>
stability: stable
synopsis: Memory mapped files for POSIX and Windows
description:
    This library provides a wrapper to mmap(2) or MapViewOfFile,
    allowing files or devices to be lazily loaded into memory as
    strict or lazy ByteStrings, ForeignPtrs or plain Ptrs, using
    the virtual memory subsystem to do on-demand loading.
    Modifications are also supported.
category: System
author: Gracjan Polak <gracjanpolak@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    System.IO.MMap
abi: e1392be4e432a9ae27d654f9ab9ed0df
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/mmap-0.5.9
library-dirs: /usr/lib/ghc-8.2.1/site-local/mmap-0.5.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/mmap-0.5.9
hs-libraries: HSmmap-0.5.9-EWtfmxbT8jF8qY63lOubUM
depends:
    base-4.10.0.0 bytestring-0.10.8.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
haddock-interfaces: /usr/share/doc/haskell-mmap/html/mmap.haddock
haddock-html: /usr/share/doc/haskell-mmap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mmap-0.5.9-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mmap.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mmap
version: 0.5.9
id: mmap-0.5.9-2C3IHFsNevT2M7ra1kTHx1
key: mmap-0.5.9-2C3IHFsNevT2M7ra1kTHx1
license: BSD3
copyright: 2008-2012, Gracjan Polak
maintainer: Gracjan Polak <gracjanpolak@gmail.com>
stability: stable
synopsis: Memory mapped files for POSIX and Windows
description:
    This library provides a wrapper to mmap(2) or MapViewOfFile,
    allowing files or devices to be lazily loaded into memory as
    strict or lazy ByteStrings, ForeignPtrs or plain Ptrs, using
    the virtual memory subsystem to do on-demand loading.
    Modifications are also supported.
category: System
author: Gracjan Polak <gracjanpolak@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    System.IO.MMap
abi: 727a9b9d6d0c434ed9e03d20b7a2c046
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mmap-0.5.9
library-dirs: /usr/lib/ghc-8.2.2/site-local/mmap-0.5.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/mmap-0.5.9
hs-libraries: HSmmap-0.5.9-2C3IHFsNevT2M7ra1kTHx1
depends:
    base-4.10.1.0 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-mmap/html/mmap.haddock
haddock-html: /usr/share/doc/haskell-mmap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
